@@ -6,7 +6,7 @@ Helpers for handling ``nargs=...`` for Parameters.
 
 from __future__ import annotations
 
-from typing import Union, Optional, Sequence, Collection, Iterable, Tuple, Set, FrozenSet
+from typing import Any, Union, Optional, Sequence, Collection, Iterable, Tuple, Set, FrozenSet
 
 __all__ = ['Nargs', 'NargsValue', 'REMAINDER', 'nargs_min_and_max_sums']
 
@@ -160,6 +160,16 @@ class Nargs:
         else:
             return count >= self.min
 
+    def max_reached(self, parsed_values: Collection[Any]) -> bool:
+        """
+        :param parsed_values: The value(s) parsed so far for a Parameter.
+        :return: True if ``parsed_values`` has a length and that length meets or exceeds the maximum count allowed,
+          False otherwise.
+        """
+        if self._has_upper_bound:
+            return len(parsed_values) >= self.max
+        return False
+
     @property
     def has_upper_bound(self) -> bool:
         return self._has_upper_bound
