@@ -154,28 +154,26 @@ class ChoiceMap(BasePositional[str], Generic[T], actions=(Concatenate,)):
     # region Argument Handling
 
     def validate(self, value: str, joined: Bool = False):
-        if not (choices := self.choices):
+        if not self.choices:
             self._no_choices_error()
 
         parsed = ctx.get_parsed_value(self)
         values = (value,) if parsed is _NotSet else (*parsed, value)
-        if (choice := ' '.join(values)) in choices:
+        if (choice := ' '.join(values)) in self.choices:
             return
         elif len(values) > self.nargs.max:
             raise BadArgument(self, 'too many values')
         prefix = choice + ' '
-        if not any(c.startswith(prefix) for c in choices if c):
-            raise InvalidChoice(self, prefix[:-1], choices)
+        if not any(c.startswith(prefix) for c in self.choices if c):
+            raise InvalidChoice(self, prefix[:-1], self.choices)
 
-    def result_value(self, command: CommandObj | None = None, missing_default: TD = _NotSet) -> Union[OptStr, TD]:
+    def result(self, command: CommandObj | None = None, missing_default: TD = _NotSet) -> Union[OptStr, TD]:
         if not self.choices:
             self._no_choices_error()
-        return super().result_value(command, missing_default)
-
-    result = result_value
+        return super().result(command, missing_default)
 
     def target(self) -> T:
-        return self.choices[self.result_value(None)].target
+        return self.choices[self.result(None)].target
 
     # endregion
 
