@@ -7,16 +7,23 @@ Utilities for working with terminals, strings, and Enums.
 from __future__ import annotations
 
 from enum import Flag, EnumMeta
+from inspect import isawaitable
 from shutil import get_terminal_size
 from time import monotonic
-from typing import Any, Callable, TypeVar, List
+from typing import Any, Callable, TypeVar, Awaitable, List
 
 try:
     from enum import CONFORM
 except ImportError:
     CONFORM = None
 
+try:
+    from wcwidth import wcwidth
+except ImportError:
+    wcwidth = len
+
 FlagEnum = TypeVar('FlagEnum', bound='FixedFlag')
+T = TypeVar('T')
 _NotSet = object()
 
 # region Text Processing / Formatting
@@ -41,6 +48,20 @@ def _parse_tree_target_repr(target) -> str:
         return repr(target)
 
 
+if wcwidth is len:
+    wcswidth = len
+else:
+
+    def wcswidth(text: str, unicode_version: str = 'auto') -> int:
+        """A version of wcswidth from the wcwidth library, optimized for how it is used in this repo."""
+        width = 0
+        for c in text:
+            if (char_width := wcwidth(c, unicode_version)) < 0:
+                return -1
+            width += char_width
+        return width
+
+
 # endregion
 
 
@@ -121,7 +142,7 @@ class FixedFlag(Flag, metaclass=FixedFlagMeta):
     def _decompose(self) -> List[FlagEnum]:
         if self._name_ is None or '|' in self._name_:  # | check is for 3.11 where pseudo-members are assigned names
             val = self._value_
-            return sorted(mem for mem in self.__class__ if (mem_val := mem._value_) & val == mem_val)  # noqa
+            return sorted(mem for mem in self.__class__ if mem._value_ & val == mem._value_)  # noqa
         return [self]
 
     def __lt__(self, other: FlagEnum) -> bool:
@@ -165,3 +186,9 @@ def positive_int(value: Any, expected: str = 'a positive integer', min_val: int
     if value < min_val:
         raise ValueError(f'Invalid {value=} - expected {expected} >= {min_val}')
     return value
+
+
+async def maybe_await(obj: T | Awaitable[T]) -> T:
+    if isawaitable(obj):
+        return await obj
+    return obj
